==> thirdparty-service-biz-1.0.45-20220111.060650-1-sources.jar: cn/com/duiba/config/FuJianBocConfig.java <==
package cn.com.duiba.config;

import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * 福建中行上送接口配置
 * @author chenzhenxing
 * @date 2021/11/12 4:01 下午
 */
@Configuration
@ConfigurationProperties(prefix = "boc.fujian")
public class FuJianBocConfig {
    /**
     * 平台公钥a
     */
//    private  String SHPublicKey = "04cda4f18ab6f8798e3b47f178d92485dd8e3917f38e66713cfb9fe60ec6369b1d744193188c457715a143a4db0945d05e3f2ec8550ccf65c9600e0cfcb5b62a0e";
    private  String SHPublicKey = "04e6bf15c11bdd455697eff9dcd2cc7e2ce8edf32a22290718371698fae6058085639771008b23a38606aa4f4c5fb281b4ee638a059a244266d8d13567f9e5b516";
    /**
     * 商户私钥b
     */
//    private String PTPrivateKeyHex = "00a5a7b543367668d7b8065cb2d1c24188ee378da2febe29b2193efe454301ad07";
    private String PTPrivateKeyHex = "37b0253152bdeffccbefff9f83173da914cd90ac9dca7c6ba9925c18483856fd";
    /**
     * 商户id，用于加签
     */
//    private String appId = "JFW7JK";
    private String appId = "U3GIe3";
    /**
     * 平台签名信息,用于验签
     */
//    private String signInfo = "zyjk_bankofchina_test";
    private String signInfo = "bankofchinafj";

//    private String url = "http://124.207.4.199/icsp";
    private String url = "https://cloud.bankofchina.com/fj/cscwkhyx/icsp";

    private String verifyUserUrl = "http://cc.tyhgg.xyz/userlogin-h5/#/userlogin/index";

    public String getSHPublicKey() {
        return SHPublicKey;
    }

    public void setSHPublicKey(String SHPublicKey) {
        this.SHPublicKey = SHPublicKey;
    }

    public String getPTPrivateKeyHex() {
        return PTPrivateKeyHex;
    }

    public void setPTPrivateKeyHex(String PTPrivateKeyHex) {
        this.PTPrivateKeyHex = PTPrivateKeyHex;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getSignInfo() {
        return signInfo;
    }

    public void setSignInfo(String signInfo) {
        this.signInfo = signInfo;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getVerifyUserUrl() {
        return verifyUserUrl;
    }

    public void setVerifyUserUrl(String verifyUserUrl) {
        this.verifyUserUrl = verifyUserUrl;
    }
}

==> thirdparty-service-biz-1.0.48-p1-20220301.021633-2-sources.jar: cn/com/duiba/config/FuJianBocConfig.java <==
package cn.com.duiba.config;

import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * 福建中行上送接口配置
 * @author chenzhenxing
 * @date 2021/11/12 4:01 下午
 */
@Configuration
@ConfigurationProperties(prefix = "boc.fujian")
public class FuJianBocConfig {
    /**
     * 平台公钥a
     */
//    private  String SHPublicKey = "04cda4f18ab6f8798e3b47f178d92485dd8e3917f38e66713cfb9fe60ec6369b1d744193188c457715a143a4db0945d05e3f2ec8550ccf65c9600e0cfcb5b62a0e";
    private  String SHPublicKey = "04e6bf15c11bdd455697eff9dcd2cc7e2ce8edf32a22290718371698fae6058085639771008b23a38606aa4f4c5fb281b4ee638a059a244266d8d13567f9e5b516";
    /**
     * 商户私钥b
     */
//    private String PTPrivateKeyHex = "00a5a7b543367668d7b8065cb2d1c24188ee378da2febe29b2193efe454301ad07";
    private String PTPrivateKeyHex = "37b0253152bdeffccbefff9f83173da914cd90ac9dca7c6ba9925c18483856fd";
    /**
     * 商户id，用于加签
     */
//    private String appId = "JFW7JK";
    private String appId = "U3GIe3";

    private String appSecret = "BFkraNE7tCrk7OjloJqUaoNpAKN0l21f";
    /**
     * 平台签名信息,用于验签
     */
//    private String signInfo = "zyjk_bankofchina_test";
    private String signInfo = "bankofchinafj";

//    private String url = "http://124.207.4.199/icsp";
    private String url = "https://cloud.bankofchina.com/fj/cscwkhyx/icsp";

    private String verifyUserUrl = "http://cc.tyhgg.xyz/userlogin-h5/#/userlogin/index";

    public String getSHPublicKey() {
        return SHPublicKey;
    }

    public void setSHPublicKey(String SHPublicKey) {
        this.SHPublicKey = SHPublicKey;
    }

    public String getPTPrivateKeyHex() {
        return PTPrivateKeyHex;
    }

    public void setPTPrivateKeyHex(String PTPrivateKeyHex) {
        this.PTPrivateKeyHex = PTPrivateKeyHex;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getAppSecret() {
        return appSecret;
    }

    public void setAppSecret(String appSecret) {
        this.appSecret = appSecret;
    }

    public String getSignInfo() {
        return signInfo;
    }

    public void setSignInfo(String signInfo) {
        this.signInfo = signInfo;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getVerifyUserUrl() {
        return verifyUserUrl;
    }

    public void setVerifyUserUrl(String verifyUserUrl) {
        this.verifyUserUrl = verifyUserUrl;
    }
}
